@@ -1,7 +1,7 @@
 /* usb.c
  *
  * Copyright (C) 2001-2004 Mariusz Woloszyn <emsi@ipartners.pl>
- * Copyright (C) 2003-2011 Marcus Meissner <marcus@jet.franken.de>
+ * Copyright (C) 2003-2014 Marcus Meissner <marcus@jet.franken.de>
  * Copyright (C) 2006-2007 Linus Walleij <triad@df.lth.se>
  *
  * This library is free software; you can redistribute it and/or
@@ -55,13 +55,14 @@
 #  define N_(String) (String)
 #endif
 
-#define CONTEXT_BLOCK_SIZE	100000
+#define CONTEXT_BLOCK_SIZE	200000
 
 #define PTP_CNT_INIT(cnt) {memset(&cnt,0,sizeof(cnt));}
 
 /* PTP2_FAST_TIMEOUT: how long (in milliseconds) we should wait for
  * an URB to come back on an interrupt endpoint */
-#define PTP2_FAST_TIMEOUT       100
+/* 100 is not enough for various cameras types. 150 seems to work better */
+#define PTP2_FAST_TIMEOUT       150
 
 /* Pack / unpack functions */
 
@@ -72,10 +73,13 @@
 uint16_t
 ptp_usb_sendreq (PTPParams* params, PTPContainer* req)
 {
-	int res;
+	int res, towrite, do_retry = TRUE;
 	PTPUSBBulkContainer usbreq;
-	unsigned long towrite;
 	Camera *camera = ((PTPData *)params->data)->camera;
+	char buf[100];
+
+	ptp_render_opcode(params, req->Code, sizeof(buf),buf);
+	GP_LOG_D ("Sending PTP_OC 0x%0x / %s request...", req->Code, buf);
 
 	/* build appropriate USB container */
 	usbreq.length=htod32(PTP_USB_BULK_REQ_LEN-
@@ -90,11 +94,19 @@ ptp_usb_sendreq (PTPParams* params, PTPContainer* req)
 	usbreq.payload.params.param5=htod32(req->Param5);
 	/* send it to responder */
 	towrite = PTP_USB_BULK_REQ_LEN-(sizeof(uint32_t)*(5-req->Nparam));
+retry:
 	res = gp_port_write (camera->port, (char*)&usbreq, towrite);
 	if (res != towrite) {
-		gp_log (GP_LOG_DEBUG, "ptp2/usb_sendreq",
-			"request code 0x%04x sending req result %d",
-			req->Code,res);
+		if (res < 0) {
+			GP_LOG_E ("PTP_OC 0x%04x sending req failed: %s (%d)", req->Code, gp_port_result_as_string(res), res);
+			if (res == GP_ERROR_IO_WRITE && do_retry) {
+				GP_LOG_D ("Clearing halt on OUT EP and retrying once.");
+				gp_port_usb_clear_halt (camera->port, GP_PORT_USB_ENDPOINT_OUT);
+				do_retry = FALSE;
+				goto retry;
+			}
+		} else
+			GP_LOG_E ("PTP_OC 0x%04x sending req failed: wrote only %d of %d bytes", req->Code, res, towrite);
 		return PTP_ERROR_IO;
 	}
 	return PTP_RC_OK;
@@ -113,7 +125,10 @@ ptp_usb_senddata (PTPParams* params, PTPContainer* ptp,
 	int progressid = 0;
 	int usecontext = (size > CONTEXT_BLOCK_SIZE);
 	GPContext *context = ((PTPData *)params->data)->context;
+	char buf[100];
 
+	ptp_render_opcode(params, ptp->Code, sizeof(buf),buf);
+	GP_LOG_D ("Sending PTP_OC 0x%0x / %s data...", ptp->Code, buf);
 	/* build appropriate USB container */
 	usbdata.length	= htod32(PTP_USB_BULK_HDR_LEN+size);
 	usbdata.type	= htod16(PTP_USB_CONTAINER_DATA);
@@ -136,9 +151,10 @@ ptp_usb_senddata (PTPParams* params, PTPContainer* ptp,
 	}
 	res = gp_port_write (camera->port, (char*)&usbdata, wlen);
 	if (res != wlen) {
-		gp_log (GP_LOG_DEBUG, "ptp2/usb_senddata",
-		"request code 0x%04x sending data error 0x%04x",
-			ptp->Code,ret);
+		if (res < 0)
+			GP_LOG_E ("PTP_OC 0x%04x sending data failed: %s (%d)", ptp->Code, gp_port_result_as_string(res), res);
+		else
+			GP_LOG_E ("PTP_OC 0x%04x sending data failed: wrote only %d of %d bytes", ptp->Code, res, wlen);
 		return PTP_ERROR_IO;
 	}
 	if (size <= datawlen) { /* nothing more to do */
@@ -156,7 +172,6 @@ ptp_usb_senddata (PTPParams* params, PTPContainer* ptp,
 	written = 0;
 	while(bytes_left_to_transfer > 0) {
 		unsigned long readlen, toread, oldwritten = written;
-		int res;
 
 		toread = 4096;
 		if (toread > bytes_left_to_transfer)
@@ -194,16 +209,14 @@ finalize:
 }
 
 static uint16_t
-ptp_usb_getpacket(PTPParams *params,
-		PTPUSBBulkContainer *packet, unsigned long *rlen)
+ptp_usb_getpacket(PTPParams *params, PTPUSBBulkContainer *packet, uint32_t *rlen)
 {
 	int		tries = 0, result;
 	Camera		*camera = ((PTPData *)params->data)->camera;
 
-	gp_log (GP_LOG_DEBUG, "ptp2/ptp_usb_getpacket", "getting next ptp packet");
 	/* read the header and potentially the first data */
 	if (params->response_packet_size > 0) {
-		gp_log (GP_LOG_DEBUG, "ptp2/ptp_usb_getpacket", "queuing buffered response packet");
+		GP_LOG_D ("Returning previously buffered response packet.");
 		/* If there is a buffered packet, just use it. */
 		memcpy(packet, params->response_packet, params->response_packet_size);
 		*rlen = params->response_packet_size;
@@ -224,7 +237,7 @@ retry:
 		return PTP_RC_OK;
 	}
 	if (result == GP_ERROR_IO_READ) {
-		gp_log (GP_LOG_DEBUG, "ptp2/usbread", "Clearing halt on IN EP and retrying once.");
+		GP_LOG_D ("Clearing halt on IN EP and retrying once.");
 		gp_port_usb_clear_halt (camera->port, GP_PORT_USB_ENDPOINT_IN);
 		/* retrying only makes sense if we did not read anything yet */
 		if (tries++ < 1)
@@ -240,192 +253,157 @@ ptp_usb_getdata (PTPParams* params, PTPContainer* ptp, PTPDataHandler *handler)
 {
 	uint16_t ret;
 	PTPUSBBulkContainer usbdata;
-	unsigned char	*data;
-	unsigned long	bytes_to_read, written, curread, oldsize;
+	unsigned char	*data = NULL;
+	uint32_t	bytes_to_read, bytes_read;
 	Camera		*camera = ((PTPData *)params->data)->camera;
-	int usecontext, progressid = 0, tries = 0, res;
+	int		report_progress, progress_id = 0, do_retry = TRUE, res = GP_OK;
 	GPContext *context = ((PTPData *)params->data)->context;
+	char buf[100];
 
-	gp_log (GP_LOG_DEBUG, "ptp2/ptp_usb_getdata", "reading data");
+	ptp_render_opcode(params, ptp->Code, sizeof(buf),buf);
+	GP_LOG_D ("Reading PTP_OC 0x%0x / %s data...", ptp->Code, buf);
 	PTP_CNT_INIT(usbdata);
-	do {
-		unsigned long len, rlen;
 
-		ret = ptp_usb_getpacket(params, &usbdata, &rlen);
-		if (ret!=PTP_RC_OK) {
-			ret = PTP_ERROR_IO;
-			break;
+	ret = ptp_usb_getpacket (params, &usbdata, &bytes_read);
+	if (ret != PTP_RC_OK)
+		goto exit;
+	if (dtoh16(usbdata.type) != PTP_USB_CONTAINER_DATA) {
+		/* We might have got a response instead. On error for instance. */
+		/* TODO: check if bytes_read == usbdata.length */
+		if (dtoh16(usbdata.type) == PTP_USB_CONTAINER_RESPONSE) {
+			params->response_packet = malloc(dtoh32(usbdata.length));
+			if (!params->response_packet) return PTP_RC_GeneralError;
+			memcpy(params->response_packet, (uint8_t *) &usbdata, dtoh32(usbdata.length));
+			params->response_packet_size = dtoh32(usbdata.length);
+			ret = PTP_RC_OK;
+		} else {
+			ret = PTP_ERROR_DATA_EXPECTED;
 		}
-		if (dtoh16(usbdata.type)!=PTP_USB_CONTAINER_DATA) {
-			/* We might have got a response instead. On error for instance. */
-			if (dtoh16(usbdata.type) == PTP_USB_CONTAINER_RESPONSE) {
-				params->response_packet = malloc(dtoh32(usbdata.length));
-				if (!params->response_packet) return PTP_RC_GeneralError;
-				memcpy(params->response_packet,
-				       (uint8_t *) &usbdata, dtoh32(usbdata.length));
-				params->response_packet_size = dtoh32(usbdata.length);
-				ret = PTP_RC_OK;
-			} else {
-				ret = PTP_ERROR_DATA_EXPECTED;
-			}
-			break;
-		}
-		if (dtoh16(usbdata.code)!=ptp->Code) {
-			/* A creative Zen device breaks down here, by leaving out
+		goto exit;
+	}
+	if (dtoh16(usbdata.code)!=ptp->Code) {
+		/* A creative Zen device breaks down here, by leaving out
 			 * Code and Transaction ID */
-			if (MTP_ZEN_BROKEN_HEADER(params)) {
-				gp_log (GP_LOG_DEBUG, "ptp2/ptp_usb_getdata", "Read broken PTP header (Code is %04x vs %04x), compensating.",
-					dtoh16(usbdata.code), ptp->Code
-				);
-				usbdata.code = dtoh16(ptp->Code);
-				usbdata.trans_id = htod32(ptp->Transaction_ID);
-			} else {
-				gp_log (GP_LOG_ERROR, "ptp2/ptp_usb_getdata", "Read broken PTP header (Code is %04x vs %04x).",
-					dtoh16(usbdata.code), ptp->Code
-				);
-				ret = PTP_ERROR_IO;
-				break;
-			}
+		if (MTP_ZEN_BROKEN_HEADER(params)) {
+			GP_LOG_D ("Read broken PTP header (Code is %04x vs %04x), compensating.",
+				  dtoh16(usbdata.code), ptp->Code);
+			usbdata.code = dtoh16(ptp->Code);
+			usbdata.trans_id = htod32(ptp->Transaction_ID);
+		} else {
+			GP_LOG_E ("Read broken PTP header (Code is %04x vs %04x).",
+				  dtoh16(usbdata.code), ptp->Code );
+			ret = PTP_ERROR_IO;
+			goto exit;
 		}
-		if (usbdata.length == 0xffffffffU) {
-			unsigned char	*data = malloc (PTP_USB_BULK_HS_MAX_PACKET_LEN_READ);
-			if (!data) return PTP_RC_GeneralError;
-			/* Copy first part of data to 'data' */
-			handler->putfunc(
-				params, handler->priv, rlen - PTP_USB_BULK_HDR_LEN, usbdata.payload.data,
-				&written
-			);
-			/* stuff data directly to passed data handler */
-			while (1) {
-				unsigned long written;
-				int result = gp_port_read (camera->port, (char*)data, PTP_USB_BULK_HS_MAX_PACKET_LEN_READ);
-				if (result < 0) {
-					free (data);
-					return PTP_ERROR_IO;
-				}
-				handler->putfunc (params, handler->priv, result, data, &written);
-				if (result < PTP_USB_BULK_HS_MAX_PACKET_LEN_READ) 
-					break;
-			}
-			free (data);
-			return PTP_RC_OK;
-		}
-		if (rlen > dtoh32(usbdata.length)) {
-			/*
-			 * Buffer the surplus response packet if it is >=
-			 * PTP_USB_BULK_HDR_LEN
-			 * (i.e. it is probably an entire package)
-			 * else discard it as erroneous surplus data.
-			 * This will even work if more than 2 packets appear
-			 * in the same transaction, they will just be handled
-			 * iteratively.
-			 *
-			 * Marcus observed stray bytes on iRiver devices;
-			 * these are still discarded.
-			 */
-			unsigned int packlen = dtoh32(usbdata.length);
-			unsigned int surplen = rlen - packlen;
-
-			if (surplen >= PTP_USB_BULK_HDR_LEN) {
-				params->response_packet = malloc(surplen);
-				if (!params->response_packet) return PTP_RC_GeneralError;
-				memcpy(params->response_packet,
-				       (uint8_t *) &usbdata + packlen, surplen);
-				params->response_packet_size = surplen;
-			} else {
-				gp_log (GP_LOG_DEBUG, "ptp2/ptp_usb_getdata", "read %ld bytes too much, expect problems!", rlen - dtoh32(usbdata.length));
-			}
-			rlen = packlen;
-		}
-
-		/* For most PTP devices rlen is 512 == sizeof(usbdata)
-		 * here. For MTP devices splitting header and data it might
-		 * be 12.
+	}
+	if (bytes_read > dtoh32(usbdata.length)) {
+		/*
+		 * Buffer the surplus response packet if it is >=
+		 * PTP_USB_BULK_HDR_LEN
+		 * (i.e. it is probably an entire package)
+		 * else discard it as erroneous surplus data.
+		 * This will even work if more than 2 packets appear
+		 * in the same transaction, they will just be handled
+		 * iteratively.
+		 *
+		 * Marcus observed stray bytes on iRiver devices;
+		 * these are still discarded.
 		 */
-		/* Evaluate full data length. */
-		len=dtoh32(usbdata.length)-PTP_USB_BULK_HDR_LEN;
+		uint32_t surplen = bytes_read - dtoh32(usbdata.length);
 
-		/* autodetect split header/data MTP devices */
-		if (dtoh32(usbdata.length) > 12 && (rlen==12))
-			params->split_header_data = 1;
-
-		/* Copy first part of data to 'data' */
-		handler->putfunc(
-			params, handler->priv, rlen - PTP_USB_BULK_HDR_LEN, usbdata.payload.data,
-			&written
-		);
-		/* Is that all of data? */
-		if (len+PTP_USB_BULK_HDR_LEN<=rlen) break;
-
-		/* If not read the rest of it. */
-retry:
-		oldsize = 0;
-		data = malloc(READLEN);
-		if (!data) return PTP_RC_GeneralError;
-		bytes_to_read = len - (rlen - PTP_USB_BULK_HDR_LEN);
-		usecontext = (bytes_to_read > CONTEXT_BLOCK_SIZE);
-		ret = PTP_RC_OK;
-		if (usecontext)
-			progressid = gp_context_progress_start (context, (bytes_to_read/CONTEXT_BLOCK_SIZE), _("Downloading..."));
-		curread = 0; res = 0;
-		while (bytes_to_read > 0) {
-			unsigned long toread = bytes_to_read;
-
-			/* read in large blobs.
-			 * if smaller than large blob, read all but the last short packet
-			 * depending on EP packetsize.
-			 */
-			if (toread > READLEN)
-				toread = READLEN;
-			else if (toread > params->maxpacketsize)
-				toread = toread - (toread % params->maxpacketsize);
-			res = gp_port_read (camera->port, (char*)data, toread);
-			if (res <= 0) {
-				ret = PTP_ERROR_IO;
-				break;
-			}
-			ret = handler->putfunc (params, handler->priv,
-				res, data, &written
-			);
-			if (ret != PTP_RC_OK)
-				break;
-			if (written != res) {
-				ret = PTP_ERROR_IO;
-				break;
-			}
-			bytes_to_read -= res;
-			curread += res;
-			if (usecontext && (oldsize/CONTEXT_BLOCK_SIZE < curread/CONTEXT_BLOCK_SIZE))
-				gp_context_progress_update (context, progressid, curread/CONTEXT_BLOCK_SIZE);
-			/* Only cancel transfers larger than 1MB. as
-			 * canceling did not work on eos_get_viewfinder of 200kb */
-			if ((rlen > 1024*1024) && gp_context_cancel(context) == GP_CONTEXT_FEEDBACK_CANCEL) {
-				ret = PTP_ERROR_CANCEL;
-				break;
-			}
-			oldsize = curread;
+		if (surplen >= PTP_USB_BULK_HDR_LEN) {
+			params->response_packet = malloc(surplen);
+			if (!params->response_packet) return PTP_RC_GeneralError;
+			memcpy(params->response_packet, (uint8_t *) &usbdata + dtoh32(usbdata.length), surplen);
+			params->response_packet_size = surplen;
+		} else {
+			GP_LOG_D ("Read %ld bytes too much, expect problems!",
+				  (long)(bytes_read - dtoh32(usbdata.length)));
 		}
-		free (data);
-		if (usecontext)
-			gp_context_progress_stop (context, progressid);
-		if (res == GP_ERROR_IO_READ) {
-			gp_log (GP_LOG_DEBUG, "ptp2/usbread", "Clearing halt on IN EP and retrying once.");
+		bytes_read = dtoh32(usbdata.length);
+	}
+
+	/* For most PTP devices rlen is 512 == sizeof(usbdata)
+	 * here. For MTP devices splitting header and data it might
+	 * be PTP_USB_BULK_HDR_LEN (12).
+	 */
+	/* autodetect split header/data MTP devices */
+	if (dtoh32(usbdata.length) > PTP_USB_BULK_HDR_LEN && (bytes_read==PTP_USB_BULK_HDR_LEN))
+		params->split_header_data = 1;
+
+	/* Copy the payload bytes we already read (with the first usb packet) */
+	ret = handler->putfunc (params, handler->priv, bytes_read - PTP_USB_BULK_HDR_LEN, usbdata.payload.data);
+	if (ret != PTP_RC_OK)
+		goto exit;
+
+	/* Check if we are done already... */
+	if (bytes_read >= dtoh32(usbdata.length))
+		goto exit;
+
+	/* If not read the rest of it. */
+	/* Make bytes_to_read contain the number of remaining payload-bytes to read. */
+	bytes_to_read = dtoh32(usbdata.length) - bytes_read;
+	/* Make bytes_read contain the number of payload-bytes already read. */
+	bytes_read -= PTP_USB_BULK_HDR_LEN;
+
+	data = malloc(READLEN);
+	if (!data) return PTP_RC_GeneralError;
+
+	report_progress = (bytes_to_read > 2*CONTEXT_BLOCK_SIZE) && (dtoh32(usbdata.length) != 0xffffffffU);
+	if (report_progress)
+		progress_id = gp_context_progress_start (context, (bytes_to_read/CONTEXT_BLOCK_SIZE), _("Downloading..."));
+	while (bytes_to_read > 0) {
+		unsigned long chunk_to_read = bytes_to_read;
+
+		/* if in read-until-short-packet mode, read one packet at a time */
+		/* else read in large blobs */
+		/* else read all but the last short packet depending on EP packetsize. */
+		if (dtoh32(usbdata.length) == 0xffffffffU)
+			chunk_to_read = PTP_USB_BULK_HS_MAX_PACKET_LEN_READ;
+		else if (chunk_to_read > READLEN)
+			chunk_to_read = READLEN;
+		else if (chunk_to_read > params->maxpacketsize)
+			chunk_to_read = chunk_to_read - (chunk_to_read % params->maxpacketsize);
+		res = gp_port_read (camera->port, (char*)data, chunk_to_read);
+		if (res == GP_ERROR_IO_READ && do_retry) {
+			GP_LOG_D ("Clearing halt on IN EP and retrying once.");
 			gp_port_usb_clear_halt (camera->port, GP_PORT_USB_ENDPOINT_IN);
-			/* retrying only makes sense if we did not read anything yet */
-			if ((tries++ < 1) && (curread == 0))
-				goto retry;
-		}
-
-		if ((ret!=PTP_RC_OK) && (ret!=PTP_ERROR_CANCEL)) {
+			/* retrying only once and only if we did not read anything yet */
+			do_retry = FALSE;
+			continue;
+		} else if (res <= 0) {
 			ret = PTP_ERROR_IO;
 			break;
+		} else
+			do_retry = FALSE; /* once we have succesfully read any data, don't try again */
+		ret = handler->putfunc (params, handler->priv, res, data);
+		if (ret != PTP_RC_OK)
+			break;
+		if (dtoh32(usbdata.length) == 0xffffffffU) {
+			/* once we have read a short packet, we are done. */
+			if (res < PTP_USB_BULK_HS_MAX_PACKET_LEN_READ)
+				bytes_to_read = 0;
+		} else
+			bytes_to_read -= res;
+		bytes_read += res;
+		if (report_progress && ((bytes_read-res)/CONTEXT_BLOCK_SIZE < bytes_read/CONTEXT_BLOCK_SIZE))
+			gp_context_progress_update (context, progress_id, bytes_read/CONTEXT_BLOCK_SIZE);
+		/* Only cancel transfers larger than 1MB. as
+		 * canceling did not work on eos_get_viewfinder of 200kb */
+		if ((bytes_read > 1024*1024) && gp_context_cancel(context) == GP_CONTEXT_FEEDBACK_CANCEL) {
+			ret = PTP_ERROR_CANCEL;
+			break;
 		}
-	} while (0);
+	}
+	if (report_progress)
+		gp_context_progress_stop (context, progress_id);
+
+exit:
+	free (data);
 
 	if ((ret!=PTP_RC_OK) && (ret!=PTP_ERROR_CANCEL)) {
-		gp_log (GP_LOG_DEBUG, "ptp2/usb_getdata",
-		"request code 0x%04x getting data error 0x%04x",
-			ptp->Code, ret);
+		GP_LOG_E ("PTP_OC 0x%04x receiving data failed: %s (0x%04x)", ptp->Code, ptp_strerror(ret, params->deviceinfo.VendorExtensionID), ret);
+		return PTP_ERROR_IO;
 	}
 	return ret;
 }
@@ -434,11 +412,11 @@ uint16_t
 ptp_usb_getresp (PTPParams* params, PTPContainer* resp)
 {
 	uint16_t 		ret;
-	unsigned long		rlen;
+	uint32_t		rlen;
 	PTPUSBBulkContainer	usbresp;
 	/*GPContext		*context = ((PTPData *)params->data)->context;*/
 
-	gp_log (GP_LOG_DEBUG, "ptp2/ptp_usb_getresp", "reading response");
+	GP_LOG_D ("Reading PTP_OC 0x%0x response...", resp->Code);
 	PTP_CNT_INIT(usbresp);
 	/* read response, it should never be longer than sizeof(usbresp) */
 	ret = ptp_usb_getpacket(params, &usbresp, &rlen);
@@ -453,7 +431,7 @@ ptp_usb_getresp (PTPParams* params, PTPContainer* resp)
 		ret = dtoh16(usbresp.code);
 	}
 	if (ret!=PTP_RC_OK) {
-		gp_log (GP_LOG_DEBUG, "ptp2/usb_getresp","request code 0x%04x getting resp error 0x%04x", resp->Code, ret);
+		GP_LOG_E ("PTP_OC 0x%04x receiving resp failed: %s (0x%04x)", resp->Code, ptp_strerror(ret, params->deviceinfo.VendorExtensionID), ret);
 		return ret;
 	}
 	/* build an appropriate PTPContainer */
@@ -462,8 +440,8 @@ ptp_usb_getresp (PTPParams* params, PTPContainer* resp)
 	resp->Transaction_ID=dtoh32(usbresp.trans_id);
 	if (resp->Transaction_ID != params->transaction_id - 1) {
 		if (MTP_ZEN_BROKEN_HEADER(params)) {
-			gp_log (GP_LOG_DEBUG, "ptp2/ptp_usb_getresp", "Read broken PTP header (transid is %08x vs %08x), compensating.",
-				resp->Transaction_ID, params->transaction_id - 1
+			GP_LOG_D ("Read broken PTP header (transid is %08x vs %08x), compensating.",
+				  resp->Transaction_ID, params->transaction_id - 1
 			);
 			resp->Transaction_ID=params->transaction_id-1;
 		}
@@ -518,19 +496,18 @@ ptp_usb_event (PTPParams* params, PTPContainer* event, int wait)
 		return PTP_ERROR_BADPARAM;
 	}
 	if (result < 0) {
-		gp_log (GP_LOG_DEBUG, "ptp2/usb_event", "reading event an error %d occurred", result);
+		GP_LOG_E ("Reading PTP event failed: %s (%d)", gp_port_result_as_string(result), result);
 		if (result == GP_ERROR_TIMEOUT)
 			return PTP_ERROR_TIMEOUT;
 		return PTP_ERROR_IO;
 	}
 	if (result == 0) {
-		gp_log (GP_LOG_DEBUG, "ptp2/usb_event", "reading event an 0 read occurred, assuming timeout.");
+		GP_LOG_E ("Reading PTP event failed: a 0 read occurred, assuming timeout.");
 		return PTP_ERROR_TIMEOUT;
 	}
 	rlen = result;
 	if (rlen < 8) {
-		gp_log (GP_LOG_ERROR, "ptp2/usb_event",
-			"reading event an short read of %ld bytes occurred", rlen);
+		GP_LOG_E ("Reading PTP event failed: only %ld bytes read", rlen);
 		return PTP_ERROR_IO;
 	}
 
@@ -540,7 +517,7 @@ ptp_usb_event (PTPParams* params, PTPContainer* event, int wait)
 	if (	(dtoh16(usbevent.type) == PTP_USB_CONTAINER_EVENT) &&
 		(dtoh32(usbevent.length) > rlen)
 	) {
-		gp_log (GP_LOG_DEBUG, "ptp2/usb_event","Canon incremental read (done: %ld, todo: %d)", rlen, dtoh32(usbevent.length));
+		GP_LOG_D ("Canon incremental read (done: %ld, todo: %d)", rlen, dtoh32(usbevent.length));
 		gp_port_get_timeout (camera->port, &timeout);
 		gp_port_set_timeout (camera->port, PTP2_FAST_TIMEOUT);
 		while (dtoh32(usbevent.length) > rlen) {
@@ -580,12 +557,11 @@ ptp_usb_control_get_extended_event_data (PTPParams *params, char *buffer, int *s
 	Camera	*camera = ((PTPData *)params->data)->camera;
 	int	ret;
 
-	gp_log (GP_LOG_DEBUG, "ptp2/get_extended_event_data", "get event data");
+	GP_LOG_D ("Getting extended event data.");
 	ret = gp_port_usb_msg_class_read (camera->port, 0x65, 0x0000, 0x0000, buffer, *size);
 	if (ret < GP_OK)
 		return PTP_ERROR_IO;
 	*size = ret;
-	gp_log_data ("ptp2/get_extended_event_data", buffer, ret);
 	return PTP_RC_OK;
 }
 
@@ -594,7 +570,7 @@ ptp_usb_control_device_reset_request (PTPParams *params) {
 	Camera	*camera = ((PTPData *)params->data)->camera;
 	int	ret;
 
-	gp_log (GP_LOG_DEBUG, "ptp2/device_reset_request", "sending reset");
+	GP_LOG_D ("Sending usb device reset request.");
 	ret = gp_port_usb_msg_class_write (camera->port, 0x66, 0x0000, 0x0000, NULL, 0);
 	if (ret < GP_OK)
 		return PTP_ERROR_IO;
@@ -609,7 +585,6 @@ ptp_usb_control_get_device_status (PTPParams *params, char *buffer, int *size) {
 	ret = gp_port_usb_msg_class_read (camera->port, 0x67, 0x0000, 0x0000, buffer, *size);
 	if (ret < GP_OK)
 		return PTP_ERROR_IO;
-	gp_log_data ("ptp2/get_device_status", buffer, ret);
 	*size = ret;
 	return PTP_RC_OK;
 }
