@@ -1,64 +1,49 @@
 var NAVTREEINDEX4 =
 {
-"gphoto2-result_8h.html#aeedb403d0eb07560182191c551dc5178":[2,0,1,7,12],
-"gphoto2-result_8h_source.html":[2,0,1,7],
-"gphoto2-setting_8c.html":[2,0,2,17],
-"gphoto2-setting_8c.html#a1061828e4e2cafb14086ac2bed47f80d":[2,0,2,17,3],
-"gphoto2-setting_8c.html#a31f5b59ba0bbc5f65f733ef299e2533d":[2,0,2,17,2],
-"gphoto2-setting_8c.html#a42d5a3f91ac1e8add4295c0d288c182f":[2,0,2,17,4],
-"gphoto2-setting_8c.html#a4b50249c04f6a48156bad839827e67b7":[2,0,2,17,5],
-"gphoto2-setting_8c.html#a6100f1cf5f3e90c2491807b6db1796af":[2,0,2,17,6],
-"gphoto2-setting_8c.html#ad3d8a3bd0c0b677acef144f2c2ef6d73":[2,0,2,17,1],
-"gphoto2-setting_8h.html":[2,0,1,8],
-"gphoto2-setting_8h.html#a4b50249c04f6a48156bad839827e67b7":[2,0,1,8,0],
-"gphoto2-setting_8h.html#a6100f1cf5f3e90c2491807b6db1796af":[2,0,1,8,1],
-"gphoto2-setting_8h_source.html":[2,0,1,8],
-"gphoto2-version_8c.html":[2,0,2,18],
 "gphoto2-version_8c.html#a039629a84ef4c735b1124901438a7468":[2,0,2,18,0],
 "gphoto2-version_8h.html":[2,0,1,9],
 "gphoto2-version_8h.html#a039629a84ef4c735b1124901438a7468":[2,0,1,9,0],
 "gphoto2-version_8h_source.html":[2,0,1,9],
 "gphoto2-widget_8c.html":[2,0,2,19],
-"gphoto2-widget_8c.html#a01706284163682eb459b045b651a2fcf":[2,0,2,19,18],
-"gphoto2-widget_8c.html#a160a340c58e006a1a4de0ac77e02e136":[2,0,2,19,16],
-"gphoto2-widget_8c.html#a20783a5aec3e3a7cd4c8ce3af7a92361":[2,0,2,19,17],
-"gphoto2-widget_8c.html#a3017f318e2dadaf82d5d55140594bcdf":[2,0,2,19,10],
-"gphoto2-widget_8c.html#a31f5b59ba0bbc5f65f733ef299e2533d":[2,0,2,19,1],
-"gphoto2-widget_8c.html#a467afee62da7ca075c8b24c71cfd812a":[2,0,2,19,8],
-"gphoto2-widget_8c.html#a4c4ea20c4d069c418399754822644174":[2,0,2,19,26],
-"gphoto2-widget_8c.html#a582ecd400d10bb040b35c317c48cf638":[2,0,2,19,28],
-"gphoto2-widget_8c.html#a58d57830ff9a7ce66b1b4b9faa93948a":[2,0,2,19,30],
-"gphoto2-widget_8c.html#a5b80fa207622d0efc676c3219c6150eb":[2,0,2,19,24],
-"gphoto2-widget_8c.html#a677590f6805dbf542d84cfe5a2718789":[2,0,2,19,32],
-"gphoto2-widget_8c.html#a6e6287e13a841e6f7631d06d72c06237":[2,0,2,19,31],
-"gphoto2-widget_8c.html#a7148abb7985c2d5d6310ef6b25d38256":[2,0,2,19,23],
-"gphoto2-widget_8c.html#a7788e7259ec60c96088f1093670e6d8d":[2,0,2,19,21],
-"gphoto2-widget_8c.html#a7a547c3a01c9ba10c8552187aca0a43f":[2,0,2,19,6],
-"gphoto2-widget_8c.html#a7a9e6b495cbdf50dfeeb9f49f58e186e":[2,0,2,19,29],
-"gphoto2-widget_8c.html#a8e84d6d4a4593ddef222d5246fa207ac":[2,0,2,19,22],
-"gphoto2-widget_8c.html#a91689d5c09fdc861080faafaf10767a7":[2,0,2,19,14],
-"gphoto2-widget_8c.html#aa46b3ea59abaafb0d83948fee80e57af":[2,0,2,19,9],
-"gphoto2-widget_8c.html#ab3365698f977ba94534148d1df5eb9d8":[2,0,2,19,3],
-"gphoto2-widget_8c.html#ac2407563a7f8c22de8df8d5009f0e4e1":[2,0,2,19,7],
-"gphoto2-widget_8c.html#acc79e22647c2cda8c053da21e296f303":[2,0,2,19,15],
-"gphoto2-widget_8c.html#ad15d33230a8a7b3d039d63bc5875c0ac":[2,0,2,19,11],
-"gphoto2-widget_8c.html#ad90a0c554f7fcc61914fd54d4c612f34":[2,0,2,19,25],
-"gphoto2-widget_8c.html#adaf6cc55afadae959d07adebecc85c65":[2,0,2,19,4],
-"gphoto2-widget_8c.html#ae0bafe1d2115b44a8cc0ba1cc82f7560":[2,0,2,19,20],
-"gphoto2-widget_8c.html#ae41c7eb76c0bb21770879ad8e1dc58b9":[2,0,2,19,2],
-"gphoto2-widget_8c.html#aed8693ca96a9d877810329fc744323f1":[2,0,2,19,13],
-"gphoto2-widget_8c.html#af3c1033ec2158a70fe987767b20d908a":[2,0,2,19,12],
-"gphoto2-widget_8c.html#af769b52499b4e6f9134d345326f59897":[2,0,2,19,19],
-"gphoto2-widget_8c.html#afa478d063b2470df8ba5ee29fc33b5bf":[2,0,2,19,5],
-"gphoto2-widget_8c.html#afee1b0fb138aa4fd73c69b5f925e5afd":[2,0,2,19,27],
+"gphoto2-widget_8c.html#a01706284163682eb459b045b651a2fcf":[2,0,2,19,17],
+"gphoto2-widget_8c.html#a160a340c58e006a1a4de0ac77e02e136":[2,0,2,19,15],
+"gphoto2-widget_8c.html#a20783a5aec3e3a7cd4c8ce3af7a92361":[2,0,2,19,16],
+"gphoto2-widget_8c.html#a3017f318e2dadaf82d5d55140594bcdf":[2,0,2,19,9],
+"gphoto2-widget_8c.html#a467afee62da7ca075c8b24c71cfd812a":[2,0,2,19,7],
+"gphoto2-widget_8c.html#a4c4ea20c4d069c418399754822644174":[2,0,2,19,25],
+"gphoto2-widget_8c.html#a582ecd400d10bb040b35c317c48cf638":[2,0,2,19,27],
+"gphoto2-widget_8c.html#a58d57830ff9a7ce66b1b4b9faa93948a":[2,0,2,19,29],
+"gphoto2-widget_8c.html#a5b80fa207622d0efc676c3219c6150eb":[2,0,2,19,23],
+"gphoto2-widget_8c.html#a677590f6805dbf542d84cfe5a2718789":[2,0,2,19,31],
+"gphoto2-widget_8c.html#a6e6287e13a841e6f7631d06d72c06237":[2,0,2,19,30],
+"gphoto2-widget_8c.html#a7148abb7985c2d5d6310ef6b25d38256":[2,0,2,19,22],
+"gphoto2-widget_8c.html#a7788e7259ec60c96088f1093670e6d8d":[2,0,2,19,20],
+"gphoto2-widget_8c.html#a7a547c3a01c9ba10c8552187aca0a43f":[2,0,2,19,5],
+"gphoto2-widget_8c.html#a7a9e6b495cbdf50dfeeb9f49f58e186e":[2,0,2,19,28],
+"gphoto2-widget_8c.html#a8e84d6d4a4593ddef222d5246fa207ac":[2,0,2,19,21],
+"gphoto2-widget_8c.html#a91689d5c09fdc861080faafaf10767a7":[2,0,2,19,13],
+"gphoto2-widget_8c.html#aa46b3ea59abaafb0d83948fee80e57af":[2,0,2,19,8],
+"gphoto2-widget_8c.html#ab3365698f977ba94534148d1df5eb9d8":[2,0,2,19,2],
+"gphoto2-widget_8c.html#ac2407563a7f8c22de8df8d5009f0e4e1":[2,0,2,19,6],
+"gphoto2-widget_8c.html#acc79e22647c2cda8c053da21e296f303":[2,0,2,19,14],
+"gphoto2-widget_8c.html#ad15d33230a8a7b3d039d63bc5875c0ac":[2,0,2,19,10],
+"gphoto2-widget_8c.html#ad90a0c554f7fcc61914fd54d4c612f34":[2,0,2,19,24],
+"gphoto2-widget_8c.html#adaf6cc55afadae959d07adebecc85c65":[2,0,2,19,3],
+"gphoto2-widget_8c.html#ae0bafe1d2115b44a8cc0ba1cc82f7560":[2,0,2,19,19],
+"gphoto2-widget_8c.html#ae41c7eb76c0bb21770879ad8e1dc58b9":[2,0,2,19,1],
+"gphoto2-widget_8c.html#aed8693ca96a9d877810329fc744323f1":[2,0,2,19,12],
+"gphoto2-widget_8c.html#af3c1033ec2158a70fe987767b20d908a":[2,0,2,19,11],
+"gphoto2-widget_8c.html#af769b52499b4e6f9134d345326f59897":[2,0,2,19,18],
+"gphoto2-widget_8c.html#afa478d063b2470df8ba5ee29fc33b5bf":[2,0,2,19,4],
+"gphoto2-widget_8c.html#afee1b0fb138aa4fd73c69b5f925e5afd":[2,0,2,19,26],
 "gphoto2-widget_8h.html":[2,0,1,10],
 "gphoto2-widget_8h.html#a01706284163682eb459b045b651a2fcf":[2,0,1,10,19],
 "gphoto2-widget_8h.html#a160a340c58e006a1a4de0ac77e02e136":[2,0,1,10,17],
 "gphoto2-widget_8h.html#a20783a5aec3e3a7cd4c8ce3af7a92361":[2,0,1,10,18],
 "gphoto2-widget_8h.html#a3017f318e2dadaf82d5d55140594bcdf":[2,0,1,10,11],
-"gphoto2-widget_8h.html#a43017455ef825f78ea479b8d3facb87f":[2,0,1,10,1],
 "gphoto2-widget_8h.html#a467afee62da7ca075c8b24c71cfd812a":[2,0,1,10,9],
 "gphoto2-widget_8h.html#a4c4ea20c4d069c418399754822644174":[2,0,1,10,27],
+"gphoto2-widget_8h.html#a4ff53441fd74eb630a997d461220f781":[2,0,1,10,1],
 "gphoto2-widget_8h.html#a582ecd400d10bb040b35c317c48cf638":[2,0,1,10,29],
 "gphoto2-widget_8h.html#a58d57830ff9a7ce66b1b4b9faa93948a":[2,0,1,10,31],
 "gphoto2-widget_8h.html#a5b80fa207622d0efc676c3219c6150eb":[2,0,1,10,25],
@@ -102,7 +87,6 @@ var NAVTREEINDEX4 =
 "jpeg_8c.html":[2,0,2,20],
 "jpeg_8c.html#a038573b7f439be589bd905b2e310490d":[2,0,2,20,11],
 "jpeg_8c.html#a1061828e4e2cafb14086ac2bed47f80d":[2,0,2,20,0],
-"jpeg_8c.html#a13e55aadc63b8d02e641b0bed4ce83e3":[2,0,2,20,14],
 "jpeg_8c.html#a157a3d714ccab9eba11a83ab8c44ef2e":[2,0,2,20,7],
 "jpeg_8c.html#a15c75310906f82a5922655361510dcf5":[2,0,2,20,24],
 "jpeg_8c.html#a2a3b3ac76f7224d6e5f635f1a831e6c7":[2,0,2,20,8],
@@ -119,17 +103,17 @@ var NAVTREEINDEX4 =
 "jpeg_8c.html#aa09238d43527626cac819e8ef6a36d54":[2,0,2,20,19],
 "jpeg_8c.html#aa921b801f3dc15f52826f9a8b43cb4e9":[2,0,2,20,10],
 "jpeg_8c.html#ab317c73e51fb8a68f86165ac831f7b8c":[2,0,2,20,1],
-"jpeg_8c.html#ab908803fc27597d9958a412937082c82":[2,0,2,20,13],
 "jpeg_8c.html#ab9d785ab5c19c852cc9d9d3cf84c64ff":[2,0,2,20,20],
+"jpeg_8c.html#ac42e2c47c8ddd27a735d598aecb6270e":[2,0,2,20,14],
 "jpeg_8c.html#acd4139fff7d6df4f514c19439a0699e6":[2,0,2,20,16],
 "jpeg_8c.html#ad12833761f2113dc7e34b802ee4b6217":[2,0,2,20,25],
 "jpeg_8c.html#ae08d9f698f1bdfc5b7a4ce0193fd177f":[2,0,2,20,9],
 "jpeg_8c.html#ae61037acbc754622dffb58feca3cea03":[2,0,2,20,23],
 "jpeg_8c.html#aee946402a45cc98e3b6489b52ae64988":[2,0,2,20,5],
+"jpeg_8c.html#afbeff88ccf50318f6063c96a1468ed20":[2,0,2,20,13],
 "jpeg_8c.html#afc52ca20abf3220442afe60db8b937b2":[2,0,2,20,21],
 "jpeg_8h.html":[2,0,2,21],
 "jpeg_8h.html#a038573b7f439be589bd905b2e310490d":[2,0,2,21,13],
-"jpeg_8h.html#a13e55aadc63b8d02e641b0bed4ce83e3":[2,0,2,21,16],
 "jpeg_8h.html#a157a3d714ccab9eba11a83ab8c44ef2e":[2,0,2,21,9],
 "jpeg_8h.html#a23992c28c13fcf5ed0906e7bb8cefa60":[2,0,2,21,3],
 "jpeg_8h.html#a2a3b3ac76f7224d6e5f635f1a831e6c7":[2,0,2,21,10],
@@ -145,8 +129,8 @@ var NAVTREEINDEX4 =
 "jpeg_8h.html#a900e68ccf955cb2c1093a5521e33adb5":[2,0,2,21,20],
 "jpeg_8h.html#a9fc326f857d0d4a8eb62180d9cfa6476":[2,0,2,21,6],
 "jpeg_8h.html#aa921b801f3dc15f52826f9a8b43cb4e9":[2,0,2,21,12],
-"jpeg_8h.html#ab908803fc27597d9958a412937082c82":[2,0,2,21,15],
 "jpeg_8h.html#ab9d785ab5c19c852cc9d9d3cf84c64ff":[2,0,2,21,22],
+"jpeg_8h.html#ac42e2c47c8ddd27a735d598aecb6270e":[2,0,2,21,16],
 "jpeg_8h.html#ad06d178d14aae0033c1c51e5728afbdd":[2,0,2,21,5],
 "jpeg_8h.html#ad06d178d14aae0033c1c51e5728afbdda2261bb2d4859330c24c587da1d8118e4":[2,0,2,21,5,0],
 "jpeg_8h.html#ad06d178d14aae0033c1c51e5728afbdda531a38469ca8aaa94805669a7b1d7721":[2,0,2,21,5,7],
@@ -160,6 +144,7 @@ var NAVTREEINDEX4 =
 "jpeg_8h.html#ae08d9f698f1bdfc5b7a4ce0193fd177f":[2,0,2,21,11],
 "jpeg_8h.html#ae61037acbc754622dffb58feca3cea03":[2,0,2,21,25],
 "jpeg_8h.html#aee946402a45cc98e3b6489b52ae64988":[2,0,2,21,7],
+"jpeg_8h.html#afbeff88ccf50318f6063c96a1468ed20":[2,0,2,21,15],
 "jpeg_8h.html#afc52ca20abf3220442afe60db8b937b2":[2,0,2,21,23],
 "jpeg_8h_source.html":[2,0,2,21],
 "pages.html":[],
@@ -231,9 +216,9 @@ var NAVTREEINDEX4 =
 "struct__CameraFile.html#ae2356552d82970aa6dc283c3d6376ec3":[1,0,2,0],
 "struct__CameraFile.html#af4d719b672fb67028a17b8f8fc0a0409":[1,0,2,3],
 "struct__CameraFileHandler.html":[1,0,3],
-"struct__CameraFileHandler.html#a35f8d8fea5283e71c06c9165a03084fc":[1,0,3,0],
-"struct__CameraFileHandler.html#a69173afefd78d998731c1d5318522754":[1,0,3,2],
-"struct__CameraFileHandler.html#ab6648ddca62242768988604017443d54":[1,0,3,1],
+"struct__CameraFileHandler.html#a5bbba5d19117be4affa56639088025cc":[1,0,3,2],
+"struct__CameraFileHandler.html#aaa08112442b99b25e1c230f61a72decc":[1,0,3,1],
+"struct__CameraFileHandler.html#ad2e1e6423213516de8194fcfd3ef4d0a":[1,0,3,0],
 "struct__CameraFileInfo.html":[1,0,4],
 "struct__CameraFileInfo.html#a1179620523bf1e56b47bcc7050b2cd76":[1,0,4,2],
 "struct__CameraFileInfo.html#a37f70742bfcbfae4e06e6bfcc235a772":[1,0,4,0],
@@ -249,5 +234,20 @@ var NAVTREEINDEX4 =
 "struct__CameraFileInfoFile.html#a6f4e10ef142ae1126784ff1f826a78fe":[1,0,6,3],
 "struct__CameraFileInfoFile.html#a78631442027c5f7134498ba323891ed3":[1,0,6,4],
 "struct__CameraFileInfoFile.html#a8b798b3031a1998be77beb5ba547cb62":[1,0,6,6],
-"struct__CameraFileInfoFile.html#a8cc5d010274aec1dfc222f1649133e2f":[1,0,6,7]
+"struct__CameraFileInfoFile.html#a8cc5d010274aec1dfc222f1649133e2f":[1,0,6,7],
+"struct__CameraFileInfoFile.html#ae7acce7dab662a7dfb088602176ac20b":[1,0,6,2],
+"struct__CameraFileInfoFile.html#af076fe6da9612a0167acf489c40f31e8":[1,0,6,1],
+"struct__CameraFileInfoPreview.html":[1,0,7],
+"struct__CameraFileInfoPreview.html#a08eb4d953d2c9f4f7e8ce54223bb8ea9":[1,0,7,3],
+"struct__CameraFileInfoPreview.html#a12d6115703a502a24cd5b193b75d666a":[1,0,7,5],
+"struct__CameraFileInfoPreview.html#a2cc5f80f66aa90d7c276df9ecd530490":[1,0,7,1],
+"struct__CameraFileInfoPreview.html#a42e378c8d0668052b39c0cca22382dd7":[1,0,7,4],
+"struct__CameraFileInfoPreview.html#a872f4d1625b0008c625138f33ef3e4cb":[1,0,7,0],
+"struct__CameraFileInfoPreview.html#a9a3b70779dc8cea4d520b9349bee6ba4":[1,0,7,2],
+"struct__CameraFilesystem.html":[1,0,8],
+"struct__CameraFilesystem.html#a1df04156f0ffe145f2e9d99eea9641ee":[1,0,8,13],
+"struct__CameraFilesystem.html#a2f676eede09ea213a0ef7e8711d6ddf3":[1,0,8,5],
+"struct__CameraFilesystem.html#a31e9fa7b813074658672a512b683a334":[1,0,8,1],
+"struct__CameraFilesystem.html#a32c4b277105e1a86ade9700dbc1cf891":[1,0,8,4],
+"struct__CameraFilesystem.html#a38fcb7940178fa609cd62b8aa9ea5c29":[1,0,8,10]
 };
